==> asn1tools-0.144.0.tar.gz: asn1tools-0.144.0/tests/files/parameterization.py <==
EXPECTED = {'Parameterization': {'extensibility-implied': False,
                      'imports': {},
                      'object-classes': {},
                      'object-sets': {},
                      'tags': 'AUTOMATIC',
                      'types': {'A': {'members': [{'name': 'a', 'type': 'B'}],
                                      'parameters': ['B'],
                                      'type': 'SEQUENCE'},
                                'A-Boolean': {'actual-parameters': [{'type': 'BOOLEAN'}],
                                              'type': 'A'},
                                'A-Integer': {'actual-parameters': [{'type': 'INTEGER'}],
                                              'type': 'A'},
                                'B': {'members': [{'name': 'a', 'type': 'A'},
                                                  {'name': 'b',
                                                   'optional': True,
                                                   'type': 'B'}],
                                      'parameters': ['A', 'B'],
                                      'type': 'SEQUENCE'},
                                'B-BooleanInteger': {'actual-parameters': [{'type': 'BOOLEAN'},
                                                                           {'type': 'INTEGER'}],
                                                     'type': 'B'},
                                'C': {'members': [{'name': 'a', 'type': 'A'},
                                                  {'actual-parameters': [{'type': 'A'},
                                                                         {'type': 'INTEGER'}],
                                                   'name': 'b',
                                                   'type': 'B'}],
                                      'parameters': ['A'],
                                      'type': 'CHOICE'},
                                'D': {'members': [{'actual-parameters': [{'type': 'B-BooleanInteger'}],
                                                   'name': 'a',
                                                   'type': 'C'},
                                                  {'members': [{'actual-parameters': [{'actual-parameters': [{'type': 'NULL'},
                                                                                                             {'type': 'INTEGER'}],
                                                                                       'type': 'B'}],
                                                                'name': 'c',
                                                                'type': 'A'},
                                                               {'actual-parameters': [{'type': 'NULL'},
                                                                                      {'type': 'INTEGER'}],
                                                                'name': 'd',
                                                                'type': 'B'}],
                                                   'name': 'b',
                                                   'type': 'CHOICE'}],
                                      'type': 'SEQUENCE'},
                                'E': {'element': {'members': [{'name': 'a',
                                                               'type': 'A'},
                                                              {'members': [{'element': {'actual-parameters': [{'type': 'A'},
                                                                                                              {'type': 'BOOLEAN'}],
                                                                                        'type': 'B'},
                                                                            'name': 'c',
                                                                            'type': 'SEQUENCE '
                                                                                    'OF'}],
                                                               'name': 'b',
                                                               'type': 'SEQUENCE'}],
                                                  'type': 'CHOICE'},
                                      'parameters': ['A'],
                                      'size': [(0, 5)],
                                      'type': 'SEQUENCE OF'},
                                'F': {'actual-parameters': [{'type': 'INTEGER'}],
                                      'type': 'E'},
                                'G': {'element': {'type': 'BOOLEAN'},
                                      'parameters': ['a'],
                                      'size': [(0, 'a')],
                                      'type': 'SEQUENCE OF'},
                                'H': {'actual-parameters': [5], 'type': 'G'},
                                'I': {'actual-parameters': ['i'], 'type': 'G'},
                                'J': {'element': {'type': 'BOOLEAN'},
                                      'parameters': ['b'],
                                      'size': ['b'],
                                      'type': 'SEQUENCE OF'},
                                'K': {'actual-parameters': [3], 'type': 'J'},
                                'L': {'parameters': ['a', 'b'],
                                      'restricted-to': [('a', 'b')],
                                      'type': 'INTEGER'},
                                'M': {'actual-parameters': [3, 9],
                                      'type': 'L'},
                                'N': {'parameters': ['a', 'B'],
                                      'restricted-to': [(-5, 'a')],
                                      'type': 'B'},
                                'O': {'actual-parameters': [-2, {'type': 'INTEGER'}],
                                      'type': 'N'}},
                      'values': {'i': {'type': 'INTEGER', 'value': 1}}}}

==> asn1tools-0.145.1.tar.gz: asn1tools-0.145.1/tests/files/parameterization.py <==
EXPECTED = {'Parameterization': {'extensibility-implied': False,
                      'imports': {},
                      'object-classes': {},
                      'object-sets': {},
                      'tags': 'AUTOMATIC',
                      'types': {'A': {'members': [{'name': 'a', 'type': 'B'}],
                                      'parameters': ['B'],
                                      'type': 'SEQUENCE'},
                                'A-Boolean': {'actual-parameters': [{'type': 'BOOLEAN'}],
                                              'type': 'A'},
                                'A-Integer': {'actual-parameters': [{'type': 'INTEGER'}],
                                              'type': 'A'},
                                'B': {'members': [{'name': 'a', 'type': 'A'},
                                                  {'name': 'b',
                                                   'optional': True,
                                                   'type': 'B'}],
                                      'parameters': ['A', 'B'],
                                      'type': 'SEQUENCE'},
                                'B-BooleanInteger': {'actual-parameters': [{'type': 'BOOLEAN'},
                                                                           {'type': 'INTEGER'}],
                                                     'type': 'B'},
                                'C': {'members': [{'name': 'a', 'type': 'A'},
                                                  {'actual-parameters': [{'type': 'A'},
                                                                         {'type': 'INTEGER'}],
                                                   'name': 'b',
                                                   'type': 'B'}],
                                      'parameters': ['A'],
                                      'type': 'CHOICE'},
                                'D': {'members': [{'actual-parameters': [{'type': 'B-BooleanInteger'}],
                                                   'name': 'a',
                                                   'type': 'C'},
                                                  {'members': [{'actual-parameters': [{'actual-parameters': [{'type': 'NULL'},
                                                                                                             {'type': 'INTEGER'}],
                                                                                       'type': 'B'}],
                                                                'name': 'c',
                                                                'type': 'A'},
                                                               {'actual-parameters': [{'type': 'NULL'},
                                                                                      {'type': 'INTEGER'}],
                                                                'name': 'd',
                                                                'type': 'B'}],
                                                   'name': 'b',
                                                   'type': 'CHOICE'}],
                                      'type': 'SEQUENCE'},
                                'E': {'element': {'members': [{'name': 'a',
                                                               'type': 'A'},
                                                              {'members': [{'element': {'actual-parameters': [{'type': 'A'},
                                                                                                              {'type': 'BOOLEAN'}],
                                                                                        'type': 'B'},
                                                                            'name': 'c',
                                                                            'type': 'SEQUENCE '
                                                                                    'OF'}],
                                                               'name': 'b',
                                                               'type': 'SEQUENCE'}],
                                                  'type': 'CHOICE'},
                                      'parameters': ['A'],
                                      'size': [(0, 5)],
                                      'type': 'SEQUENCE OF'},
                                'F': {'actual-parameters': [{'type': 'INTEGER'}],
                                      'type': 'E'},
                                'G': {'element': {'type': 'BOOLEAN'},
                                      'parameters': ['a'],
                                      'size': [(0, 'a')],
                                      'type': 'SEQUENCE OF'},
                                'H': {'actual-parameters': [5], 'type': 'G'},
                                'I': {'actual-parameters': ['i'], 'type': 'G'},
                                'J': {'element': {'type': 'BOOLEAN'},
                                      'parameters': ['b'],
                                      'size': ['b'],
                                      'type': 'SEQUENCE OF'},
                                'K': {'actual-parameters': [3], 'type': 'J'},
                                'L': {'parameters': ['a', 'b'],
                                      'restricted-to': [('a', 'b')],
                                      'type': 'INTEGER'},
                                'M': {'actual-parameters': [3, 9], 'type': 'L'},
                                'N': {'parameters': ['a', 'B'],
                                      'restricted-to': [(-5, 'a')],
                                      'type': 'B'},
                                'O': {'actual-parameters': [-2,
                                                            {'type': 'INTEGER'}],
                                      'type': 'N'}},
                      'values': {'i': {'type': 'INTEGER', 'value': 1}}}}
